# Copyright (C) 2016-2023 RhodeCode GmbH
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License, version 3
# (only), as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# This program is dual-licensed. If you wish to learn more about the
# RhodeCode Enterprise Edition, including its added features, Support services,
# and proprietary license terms, please see https://rhodecode.com/licenses/
import os
from rhodecode.apps.file_store import config_keys
from rhodecode.config.settings_maker import SettingsMaker


def _sanitize_settings_and_apply_defaults(settings):
    """
    Set defaults, convert to python types and validate settings.
    """
    settings_maker = SettingsMaker(settings)

    settings_maker.make_setting(config_keys.enabled, True, parser='bool')
    settings_maker.make_setting(config_keys.backend, 'local')

    default_store = os.path.join(os.path.dirname(settings['__file__']), 'upload_store')
    settings_maker.make_setting(config_keys.store_path, default_store)

    settings_maker.env_expand()


def includeme(config):
    from rhodecode.apps.file_store.views import FileStoreView

    settings = config.registry.settings
    _sanitize_settings_and_apply_defaults(settings)

    config.add_route(
        name='upload_file',
        pattern='/_file_store/upload')
    config.add_view(
        FileStoreView,
        attr='upload_file',
        route_name='upload_file', request_method='POST', renderer='json_ext')

    config.add_route(
        name='download_file',
        pattern='/_file_store/download/{fid:.*}')
    config.add_view(
        FileStoreView,
        attr='download_file',
        route_name='download_file')

    config.add_route(
        name='download_file_by_token',
        pattern='/_file_store/token-download/{_auth_token}/{fid:.*}')
    config.add_view(
        FileStoreView,
        attr='download_file_by_token',
        route_name='download_file_by_token')
